{% extends "template.html" %}
{% from "_formhelpers.html" import render_field %}

{% block content %}
  <h2>
    {% if update %}
      Edit
    {% else %}
      Create new
    {% endif %}
    {{class_single_name}}
  </h2>
  <form method="post" action="/new/{{class_name}}">
    <dl>
      {% for field in form%}
          {{ render_field(field) }}
      {% endfor %}
    </dl>
    <input type="submit" value="Save">
  </form>
{% endblock %}
