{% extends "template.html" %}
{% from "_formhelpers.html" import render_field %}

{% block content %}
  <h2>
    Something went wrong 
  </h2>
  <p>
    {% if message  %}
        {{message|safe}} 
    {% else  %}
        Blame the develper.
    {% endif  %}
  </p>
{% endblock %}
