{% extends "template.html" %}
{% from "_formhelpers.html" import render_field %}

{% block content %}
  <h2>
    Confirm Deletion 
  </h2>
  <form method="post" action="/delete/{{class_name}}/{{pk}}">
    <p>Are you sure you want to delete <strong>{{element}}</strong>?</p>
    <input type="submit" value="Delete">
  </form>
{% endblock %}
