{% extends "template.html" %}
{% block content %}
  <h2>Data sources</h2>
  <h3>Common data</h3>
  {% for class in classes.0 %}
      <a href="{{ class }}">{{ class }}</a><br>
  {% endfor %}
  <h3>Data from selected code</h3>
  {% for class in classes.1 %}
      <a href="{{ class }}">{{ class }}</a><br>
  {% endfor %}
{% endblock %}
