<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <title>{{title}}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="">
    <meta name="author" content="">

    <!-- Le styles -->
    <link href="/media/bootstrap/css/bootstrap.min.css" rel="stylesheet">
    <style>
      body {
        padding-top: 60px; /* 60px to make the container go all the way to the bottom of the topbar */
      }
    </style>
    <link href="/media/bootstrap/css/bootstrap-responsive.css" rel="stylesheet">

    <!-- HTML5 shim, for IE6-8 support of HTML5 elements -->
    <!--[if lt IE 9]>
      <script src="http://html5shim.googlecode.com/svn/trunk/html5.js"></script>
    <![endif]-->

    <!-- Fav and touch icons -->
    <link rel="apple-touch-icon-precomposed" sizes="144x144" href="/media/bootstrap/ico/apple-touch-icon-144-precomposed.png">
    <link rel="apple-touch-icon-precomposed" sizes="114x114" href="/media/bootstrap/ico/apple-touch-icon-114-precomposed.png">
      <link rel="apple-touch-icon-precomposed" sizes="72x72" href="/media/bootstrap/ico/apple-touch-icon-72-precomposed.png">
                    <link rel="apple-touch-icon-precomposed" href="/media/bootstrap/ico/apple-touch-icon-57-precomposed.png">
                                   <link rel="shortcut icon" href="/media/bootstrap/ico/favicon.png">
  </head>

  <body>
    <div class="navbar navbar-fixed-top">
      <div class="navbar-inner">
        <div class="container">
          <a class="btn btn-navbar" data-toggle="collapse" data-target=".nav-collapse">
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
          </a>
          <a class="brand" href="/">{{title}}</a>
          <div class="nav-collapse collapse">
            <ul class="nav">
              <li class="dropdown">
              <a data-toggle="dropdown" class="dropdown-toggle"
                href="#">({{data_code}})<b class="caret"></b></a>
                <ul class="dropdown-menu">
                    {% for code in data_codes %}
                    <li><a href="/change-data-code/{{code}}">{{code}}</a></li>
                    {% endfor %}
                </ul>
              </li>
              <li><a href="http://havaiana.rtfd.org" target="_blank">Havaiana docs</a></li>
              <li><a href="http://ojota.rtfd.org" target="_blank">Ojota docs</a></li>
            </ul>
          </div><!--/.nav-collapse -->
        </div>
      </div>
    </div>

    <div class="container">
      {% with messages = get_flashed_messages() %}
        {% if messages %}
        <ul class=flashes>
            {% for message in messages %}
              <div class="alert alert-success">
                <!--<a class="close">×</a>-->
                {{ message }}
              </div>     
            {% endfor %}
          </ul>
        {% endif %}
      {% endwith %}
      
      {% block content %}

      {% endblock %}
      <div class="pull-right">
        Rendered with love, magic and Python using <a
        href="http://havaiana.rtfd.org" target="_blank">Havaiana</a>
      </div>
    </div> <!-- /container -->

    <!-- Le javascript
    ================================================== -->
    <!-- Placed at the end of the document so the pages load faster -->
    <script src="/media/jquery.js"></script>
    <script src="/media/bootstrap/js/bootstrap-dropdown.js"></script>
    <script src="/media/bootstrap/js/bootstrap-alert.js"></script>
  </body>
</html>

